#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Feb  2 16:20:32 2021

@author: tardis
"""
from . import annotate_identified_variants
from annotate_identified_variants import annotate_mutations

__all__ = ['annotate_identified_variants', 'annotate_identified_variants.annotate_mutations']
